@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ecLib.php 4392 2011-10-13 13:04:01Z fishbone $
+ * @version    SVN: $Id: ecLib.php 4504 2011-12-16 05:42:48Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(dirname(__FILE__) . '/ecLibDb.php');
@@ -34,16 +34,18 @@ class ecLib
 	{
 		// DBオブジェクト作成
 		$this->db = new ecLibDb();
+		
+		// オブジェクトを初期化
+		$this->_initByDefault();
 	}
 	/**
 	 * オブジェクトをデフォルト通貨、言語で初期化
 	 */
-	public function initByDefault()
+	public function _initByDefault()
 	{
 		global $gEnvManager;
 		
 		$type = $this->db->getDefaultCurrency();
-		//$lang = $this->db->getDefaultLanguage();
 		$lang = $gEnvManager->getDefaultLanguage();
 		$this->setCurrencyType($type, $lang);
 	}
