@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_base.sql 4839 2012-04-11 01:39:22Z fishbone $
+-- * @version    SVN: $Id: create_base.sql 4996 2012-06-28 03:42:28Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -82,6 +82,7 @@ CREATE TABLE _operation_log (
     ol_link_url          TEXT                                         NOT NULL,      -- リンク用URL
     ol_search_option     TEXT                                         NOT NULL,      -- 検索用補助データ
     ol_checked           BOOLEAN        DEFAULT false                 NOT NULL,      -- メッセージ確認状況
+    ol_widget_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 実行ウィジェットID(ファイル名)
     ol_method            TEXT                                         NOT NULL,      -- 実行メソッド
     ol_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログシリアル番号
     ol_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 記録日時
@@ -330,6 +331,8 @@ CREATE TABLE _access_log (
     al_user_agent        TEXT                                         NOT NULL,      -- アクセスプログラム
     al_accept_language   VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- クライアントの認識可能言語
     al_path              VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセスポイントパス
+    al_cookie            BOOLEAN        DEFAULT false                 NOT NULL,      -- クッキーがあるかどうか
+    al_crawler           BOOLEAN        DEFAULT false                 NOT NULL,      -- クローラかどうか
     al_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- アクセス日時
     PRIMARY KEY          (al_serial)
 ) TYPE=innodb;
@@ -730,6 +733,7 @@ CREATE TABLE _page_def (
     pd_editable          BOOLEAN        DEFAULT true                  NOT NULL,      -- データ編集可能かどうか
     pd_title_visible     BOOLEAN        DEFAULT true                  NOT NULL,      -- タイトルを表示するかどうか
     pd_use_render        BOOLEAN        DEFAULT true                  NOT NULL,      -- Joomla!の描画処理を使用するかどうか
+    pd_password          CHAR(32)       DEFAULT ''                    NOT NULL,      -- アクセス制限パスワード(MD5)
     pd_cache_dt          TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- キャッシュ更新日時
     pd_active_start_dt   TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- アクセス可能期間(開始)
     pd_active_end_dt     TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- アクセス可能期間(終了)
@@ -870,6 +874,7 @@ CREATE TABLE _menu_def (
     md_link_url          TEXT                                         NOT NULL,      -- リンク先
     md_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- リンク先のコンテンツの種別
     md_content_id        VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- リンク先のコンテンツのID
+    md_enable            BOOLEAN        DEFAULT true                  NOT NULL,      -- 使用可能かどうか
     md_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
 
     md_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
