@@ -7,7 +7,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: fckconfig.js 3726 2010-10-24 09:15:09Z fishbone $
+ * @version    SVN: $Id: fckconfig.js 3743 2010-10-27 02:29:43Z fishbone $
  * @link       http://www.magic3.org
  */
 FCKConfig.EnterMode = 'div' ;			// p | div | br
@@ -36,8 +36,10 @@ if (window.parent) FCKConfig.GoogleMaps_Key = window.parent.M3_GOOGLE_MAPS_KEY;
 
 // プラグインの追加
 FCKConfig.Plugins.Add('FileBrowser_Thumbnail', 'en,ja');// ファイルブラウザ
-FCKConfig.Plugins.Add('Blink', 'en,ja');// 携帯用blinkタグ
+//FCKConfig.Plugins.Add('Blink', 'en,ja');// 携帯用blinkタグ
+FCKConfig.Plugins.Add('Blink2', 'en,ja');// 携帯用blinkタグ
 FCKConfig.Plugins.Add('Marquee', 'en,ja');// 携帯用marqueeタグ
+//FCKConfig.Plugins.Add('Marquee2', 'en,ja');// 携帯用marqueeタグ
 FCKConfig.Plugins.Add('Emoji', 'en,ja');// 携帯用絵文字タグ
 FCKConfig.Plugins.Add('MobileLink', 'en,ja');// 携帯用リンクタグ
 FCKConfig.Plugins.Add('googlemaps', 'en,ja');// Googleマップ
@@ -68,11 +70,11 @@ FCKConfig.ToolbarSets["M3MobileDefault"] = [
 	['Cut','Copy','Paste','PasteText','PasteWord'],
 	['Undo','Redo','-','Find','Replace','-','SelectAll','RemoveFormat'],
 	'/',
-	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript','-','Blink','Marquee'],
+	['Bold','Italic','Underline','StrikeThrough','-','Subscript','Superscript','-','Blink2','Marquee'],
 	['OrderedList','UnorderedList','-','Outdent','Indent','Blockquote'],
 	['JustifyLeft','JustifyCenter','JustifyRight','JustifyFull'],
 	['MobileLink','Unlink','Anchor'],
-	['Image','Flash','Table','Rule','Smiley','Emoji','SpecialChar','PageBreak'],
+	['Image','Flash','Table','Rule','Emoji','SpecialChar','PageBreak'],
 	'/',
 	['Style','FontFormat','FontName','FontSize'],
 	['TextColor','BGColor'],
