@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTestWidgetContainer.php 4954 2012-06-09 10:10:41Z fishbone $
+ * @version    SVN: $Id: admin_mainTestWidgetContainer.php 4965 2012-06-13 12:22:50Z fishbone $
  * @link       http://www.magic3.org
  */
 //require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -58,8 +58,6 @@ class admin_mainTestWidgetContainer extends admin_mainBaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-	echo "debug testing...";
-	debug("debug testing...");
 	//$ret = $this->gInstance->getImageManager()->createDefaultThumb(M3_VIEW_TYPE_PHOTO, '123', '/var/www/html/magic3/resource/image/1.jpg');
 /*
 		// 契約番号(8桁) オンライン登録時に発行された契約番号を入力してください。
