@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_menu3WidgetContainer.php 4990 2012-06-21 22:50:15Z fishbone $
+ * @version    SVN: $Id: admin_menu3WidgetContainer.php 5000 2012-07-01 13:30:26Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -281,9 +281,9 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			// アイコン作成
 			$iconTitle = 'PC画面プレビュー';
 			$iconUrl = $this->gEnv->getRootUrl() . self::PC_ICON_FILE;
-			$iconTag = '<span class="static"><a href="#" onclick="m3ShowPreviewWindow(0, \'' . $this->gEnv->getDefaultUrl() . '\');return false;">';
+			$iconTag = '<div class="static"><a href="#" onclick="m3ShowPreviewWindow(0, \'' . $this->gEnv->getDefaultUrl() . '\');return false;">';
 			$iconTag .= '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::PREVIEW_ICON_SIZE . '" height="' . self::PREVIEW_ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" /></a>';
-			$iconTag .= $this->createContentMenu(0) . '</span>';		// コンテンツ編集メニュー付加
+			$iconTag .= $this->createContentMenu(0) . '</div>';		// コンテンツ編集メニュー付加
 			$previewTag .= $iconTag;
 		}
 		// スマートフォン用サイト
@@ -291,9 +291,9 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			// アイコン作成
 			$iconTitle = 'スマートフォン画面プレビュー';
 			$iconUrl = $this->gEnv->getRootUrl() . self::SMARTPHONE_ICON_FILE;
-			$iconTag = '<span class="static"><a href="#" onclick="m3ShowPreviewWindow(2, \'' . $this->gEnv->getDefaultSmartphoneUrl() . '\');return false;">';
+			$iconTag = '<div class="static"><a href="#" onclick="m3ShowPreviewWindow(2, \'' . $this->gEnv->getDefaultSmartphoneUrl() . '\');return false;">';
 			$iconTag .= '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::PREVIEW_ICON_SIZE . '" height="' . self::PREVIEW_ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" /></a>';
-			$iconTag .= $this->createContentMenu(2) . '</span>';		// コンテンツ編集メニュー付加
+			$iconTag .= $this->createContentMenu(2) . '</div>';		// コンテンツ編集メニュー付加
 			$previewTag .= $iconTag;
 		}
 		// 携帯用サイト
@@ -301,9 +301,9 @@ class admin_menu3WidgetContainer extends BaseAdminWidgetContainer
 			// アイコン作成
 			$iconTitle = '携帯画面プレビュー';
 			$iconUrl = $this->gEnv->getRootUrl() . self::MOBILE_ICON_FILE;
-			$iconTag = '<span class="static"><a href="#" onclick="m3ShowPreviewWindow(1, \'' . $this->gEnv->getDefaultMobileUrl() . '\');return false;">';
+			$iconTag = '<div class="static"><a href="#" onclick="m3ShowPreviewWindow(1, \'' . $this->gEnv->getDefaultMobileUrl() . '\');return false;">';
 			$iconTag .= '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::PREVIEW_ICON_SIZE . '" height="' . self::PREVIEW_ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" /></a>';
-			$iconTag .= $this->createContentMenu(1) . '</span>';		// コンテンツ編集メニュー付加
+			$iconTag .= $this->createContentMenu(1) . '</div>';		// コンテンツ編集メニュー付加
 			$previewTag .= $iconTag;
 		}
 		return $previewTag;
