@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: banner3WidgetContainer.php 4512 2011-12-21 11:29:46Z fishbone $
+ * @version    SVN: $Id: banner3WidgetContainer.php 4850 2012-04-14 06:22:48Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -94,7 +94,9 @@ class banner3WidgetContainer extends BaseWidgetContainer
 			return;
 		}
 		// バナー定義が取得できたときは、バナーを画面に出力
-		if (!empty($this->record)){
+		if (empty($this->record)){
+			$this->cancelParse();		// 出力しない
+		} else {
 			$itemArray = explode(',', $this->record['bd_item_id']);
 			if (count($itemArray) > 0){
 				// 表示するバナー項目を決定する
@@ -194,10 +196,14 @@ class banner3WidgetContainer extends BaseWidgetContainer
 					if (empty($row['bi_link_url'])){
 						$link = $destImg;
 					} else {			// リンク先が設定されているとき
+						// デフォルトのリンクURLを取得
+						$this->parseLinkUrl($row['bi_link_url'], $defaultLinkUrl, $tmp);
+						
 						$linkUrl  = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_DO_WIDGET;
 						$linkUrl .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
 						if (!empty($key)) $linkUrl .= '&stamp=' . $key;
-						$linkUrl .= '&url=' . urlencode($row['bi_link_url']);		// URLはエンコードする
+						//$linkUrl .= '&url=' . urlencode($row['bi_link_url']);		// URLはエンコードする
+						$linkUrl .= '&url=' . urlencode($defaultLinkUrl);		// URLはエンコードする
 						$link = '<a style="margin:0;padding:0;" href="' . $this->convertUrlToHtmlEntity($this->getUrl($linkUrl)) . '"';
 						if (!empty($targetType)) $link .= ' target="' . $targetType . '"';		// リンクターゲット
 						$link .= '>';
@@ -244,5 +250,35 @@ class banner3WidgetContainer extends BaseWidgetContainer
 	{
 		return $this->headCss;
 	}
+	/**
+	 * リンク先URLを解析する
+	 *
+	 * @param string $srcStr		解析元文字列
+	 * @param string $url_default	リンク先URL(デフォルト)
+	 * @param array $urls			リンク先URL(デフォルト以外)
+	 * @return bool					true=成功、false=失敗
+	 */
+	function parseLinkUrl($srcStr, &$url_default, &$urls)
+	{
+		// 初期化
+		$url_default = '';
+		$urls = array();
+		
+		$urlArray = explode(';', $srcStr);
+		for ($i = 0; $i < count($urlArray); $i++){
+			$lineStr = trim($urlArray[$i]);
+			if (empty($lineStr)) continue;
+			
+			$pos = strpos($lineStr, '|');
+			if ($pos === false){
+				$url_default = $lineStr;
+			} else {
+				list($deviceType, $url) = explode('|', $lineStr);
+				$deviceType = trim($deviceType);
+				$urls[$deviceType] = trim($url);
+			}
+		}
+		return true;
+	}
 }
 ?>
