@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: contactusWidgetContainer.php 3608 2010-09-21 01:58:12Z fishbone $
+ * @version    SVN: $Id: contactusWidgetContainer.php 4949 2012-06-09 08:52:24Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
@@ -19,7 +19,6 @@ require_once($gEnvManager->getCurrentWidgetDbPath() .	'/contactus_mainDb.php');
 class contactusWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;		// システムDBオブジェクト
 	private $langId;	// 表示言語
 	private $state;		// 都道府県
 	const CONTACTUS_FORM = 'contact_us';		// お問い合わせフォーム
@@ -37,7 +36,6 @@ class contactusWidgetContainer extends BaseWidgetContainer
 		
 		// DBオブジェクト作成
 		$this->db = new contactus_mainDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 	}
 	/**
 	 * テンプレートファイルを設定
