@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2007 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: content_search_boxWidgetContainer.php 1320 2008-12-06 07:00:59Z fishbone $
+ * @version    SVN: $Id: content_search_boxWidgetContainer.php 2623 2009-12-05 12:40:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -18,6 +18,7 @@ require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
 class content_search_boxWidgetContainer extends BaseWidgetContainer
 {
 	const TARGET_WIDGET = 'default_content';		// 呼び出しウィジェットID
+	const DEFAULT_TITLE = 'コンテンツ検索';			// デフォルトのウィジェットタイトル
 	
 	/**
 	 * コンストラクタ
@@ -58,11 +59,20 @@ class content_search_boxWidgetContainer extends BaseWidgetContainer
 			$keyword = $request->trimValueOf('keyword');
 			
 			// ブログメインに検索結果を表示させる
-			$url = $this->gPage->createWidgetCmdUrl('', self::TARGET_WIDGET, $this->gEnv->getCurrentWidgetId(), 'act=search&keyword=' . urlencode($keyword));
+			$url = $this->gPage->createWidgetCmdUrl(self::TARGET_WIDGET, $this->gEnv->getCurrentWidgetId(), 'act=search&keyword=' . urlencode($keyword));
 			$this->gPage->redirect($url);
 		}
-		// メニューテーブルのパラメータ
-		$this->tmpl->addVar("_widget", "default_menu_param", $this->gDesign->getDefaultWidgetTableParam());
+	}
+	/**
+	 * ウィジェットのタイトルを設定
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
+	 * @return string 						ウィジェットのタイトル名
+	 */
+	function _setTitle($request, &$param)
+	{
+		return self::DEFAULT_TITLE;
 	}
 }
 ?>
