@@ -10,20 +10,23 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 4974 2012-06-16 02:24:17Z fishbone $
+ * @version    SVN: $Id: admin_default_contentContentWidgetContainer.php 5027 2012-07-09 06:24:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
+require_once($gEnvManager->getLibPath()			. '/qqFileUploader/fileuploader.php');
 
 class admin_default_contentContentWidgetContainer extends admin_default_contentBaseWidgetContainer
 {
 	private $serialNo;		// 選択中の項目のシリアル番号
 	private $serialArray = array();		// 表示されているコンテンツシリアル番号
 	private $selectedItem = array();	// 選択中の項目
+	private $attachFileInfoArray;		// 添付ファイルの情報
 	private $completed;			// データ登録完了かどうか
 	private $isExistsContent;		// コンテンツ項目が存在するかどうか
 	private $isMultiLang;			// 多言語対応画面かどうか
 	const ICON_SIZE = 16;		// アイコンのサイズ
+	const PANEL_BUTTON_SIZE = 32;	// 拡張エリア制御ボタンサイズ
 	const INC_INDEX = 1;		// メニュー項目表示順の増加分
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理ウィジェットのウィジェットID
 	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
@@ -31,6 +34,8 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 	const INACTIVE_ICON_FILE = '/images/system/inactive.png';		// 非公開アイコン
 	const ADD_TO_MENU_ICON_FILE = '/images/system/addtomenu.png';		// メニューに追加用アイコン
 	const PREVIEW_ICON_FILE = '/images/system/preview.png';		// プレビュー用アイコン
+	const OPEN_PANEL_ICON_FILE = '/images/system/plus32.png';		// 拡張エリア表示用アイコン
+	const CLOSE_PANEL_ICON_FILE = '/images/system/minus32.png';		// 拡張エリア非表示用アイコン
 	const LANG_ICON_PATH = '/images/system/flag/';		// 言語アイコンパス
 	const MSG_UPDATE_CONTENT = 'コンテンツを更新しました';			// コンテンツ更新メッセージ
 	const DEFAULT_SEARCH_KEY = '1';			// デフォルトの検索キー(更新日時)
@@ -160,6 +165,17 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				//} else {
 				//	$ret = self::$_mainDb->delContentItem($delItems);
 				//}
+				
+				// ##### 添付ファイルをコンテンツIDで削除 #####
+				if ($ret){
+					for ($i = 0; $i < count($delContentInfo); $i++){
+						$infoObj = $delContentInfo[$i];
+						$ret = $this->gInstance->getFileManager()->delAttachFileInfoByContentId(default_contentCommonDef::$_viewContentType,
+																								$infoObj->contentId, default_contentCommonDef::getAttachFileDir());
+						if (!$ret) break;
+					}
+				}
+
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					
@@ -291,6 +307,20 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		}
 		if (!empty($end_time)) $end_time = $this->convertToProperTime($end_time, 1/*時分フォーマット*/);
 		
+		// 添付ファイルリスト取得
+		$attachFileCount = $request->trimValueOf('attachfilecount');		// 添付ファイル数
+		$fileTitles	= $request->trimValueOf('item_filetitle');		// 添付ファイルタイトル
+		$filenames	= $request->trimValueOf('item_filename');		// 添付ファイルファイル名
+		$fileIds	= $request->trimValueOf('item_fileid');		// 添付ファイルファイルID
+		$this->attachFileInfoArray = array();
+		for ($i = 0; $i < $attachFileCount; $i++){
+			$newInfoObj = new stdClass;
+			$newInfoObj->title		= $fileTitles[$i];
+			$newInfoObj->filename	= $filenames[$i];
+			$newInfoObj->fileId		= $fileIds[$i];
+			$this->attachFileInfoArray[] = $newInfoObj;
+		}
+		
 		$reloadData = false;		// データの再読み込み
 		$hasPassword = false;		// パスワードが設定されているかどうか
 		$histryIndex = -1;	// 履歴番号
@@ -318,13 +348,25 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				}
 				
 				if ($this->isMultiLang){		// 多言語対応の場合
-					//$contentId = $request->trimValueOf('contentid');		// コンテンツID
 					$ret = self::$_mainDb->addContentItem(default_contentCommonDef::$_contentType, $contentId, $this->langId, $name, ''/*説明*/, $html, $visible, $default, $limited, $key, $password, 
 														$metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial);
 				} else {
 					$ret = self::$_mainDb->addContentItem(default_contentCommonDef::$_contentType, 0, $this->langId, $name, ''/*説明*/, $html, $visible, $default, $limited, $key, $password, 
 														$metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial);
 				}
+				// ##### 添付ファイル情報を更新 #####
+				if ($ret){
+					$ret = self::$_mainDb->getContentBySerial($newSerial, $row);
+					if ($ret){
+						$contentId = $row['cn_id'];		// コンテンツID
+						$name = $row['cn_name'];		// コンテンツ名前
+						$attachFileDir = default_contentCommonDef::getAttachFileDir();
+					
+						$ret = $this->gInstance->getFileManager()->updateAttachFileInfo(default_contentCommonDef::$_viewContentType, $contentId, 0, $newSerial,
+																															$this->attachFileInfoArray, $attachFileDir);
+					}
+				}
+
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
 					// シリアル番号更新
@@ -339,11 +381,11 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					if ($ret) $this->setGuidanceMsg('更新情報をサーバへアップしました');
 					
 					// 運用ログを残す
-					$ret = self::$_mainDb->getContentBySerial($this->serialNo, $row);
+/*					$ret = self::$_mainDb->getContentBySerial($this->serialNo, $row);
 					if ($ret){
 						$contentId = $row['cn_id'];		// コンテンツID
 						$name = $row['cn_name'];		// コンテンツ名前
-					}
+					}*/
 					$contentAttr = default_contentCommonDef::$_deviceTypeName;
 					if ($this->isMultiLang) $contentAttr .= $this->getLangName($this->langId);		// 多言語対応の場合
 					$this->gOpeLog->writeUserInfo(__METHOD__, sprintf(self::LOG_MSG_ADD_CONTENT, $contentAttr, $name), 2100, 'ID=' . $contentId);
@@ -375,6 +417,19 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				}
 				
 				$ret = self::$_mainDb->updateContentItem($this->serialNo, $name, $html, $visible, $default, $limited, $key, $password, $metaTitle, $metaDesc, $metaKeyword, $startDt, $endDt, $newSerial);
+				// ##### 添付ファイル情報を更新 #####
+				if ($ret){
+					$ret = self::$_mainDb->getContentBySerial($newSerial, $row);
+					if ($ret){
+						$contentId = $row['cn_id'];		// コンテンツID
+						$name = $row['cn_name'];		// コンテンツ名前
+						$attachFileDir = default_contentCommonDef::getAttachFileDir();
+					
+						$ret = $this->gInstance->getFileManager()->updateAttachFileInfo(default_contentCommonDef::$_viewContentType, $contentId, $this->serialNo, $newSerial,
+																															$this->attachFileInfoArray, $attachFileDir);
+					}
+				}
+				
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
 					// シリアル番号更新
@@ -392,11 +447,11 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					if ($ret) $this->setGuidanceMsg('更新情報をサーバへアップしました');
 					
 					// 運用ログを残す
-					$ret = self::$_mainDb->getContentBySerial($this->serialNo, $row);
+/*					$ret = self::$_mainDb->getContentBySerial($this->serialNo, $row);
 					if ($ret){
 						$contentId = $row['cn_id'];		// コンテンツID
 						$name = $row['cn_name'];		// コンテンツ名前
-					}
+					}*/
 					$contentAttr = default_contentCommonDef::$_deviceTypeName;
 					if ($this->isMultiLang) $contentAttr .= $this->getLangName($this->langId);		// 多言語対応の場合
 					$this->gOpeLog->writeUserInfo(__METHOD__, sprintf(self::LOG_MSG_UPDATE_CONTENT, $contentAttr, $name), 2100, 'ID=' . $contentId);
@@ -417,17 +472,30 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					$name = $row['cn_name'];		// コンテンツ名前
 				}
 
+				$delByContentId = true;		// コンテンツをコンテンツIDで削除するかどうか
 				if ($this->isMultiLang){		// 多言語対応のとき
 					if ($this->langId == $this->gEnv->getDefaultLanguage()){		// デフォルト言語のときは全削除
 						$ret = self::$_mainDb->delContentItemById(array($this->serialNo));
 					} else {
 						$ret = self::$_mainDb->delContentItem(array($this->serialNo));
+						$delByContentId = false;		// コンテンツをコンテンツIDで削除するかどうか
 					}
 				} else {
 					// 多言語対応状態に関わらずコンテンツIDで削除
 					$ret = self::$_mainDb->delContentItemById(array($this->serialNo));
-					//$ret = self::$_mainDb->delContentItem(array($this->serialNo));
 				}
+				
+				// ##### 添付ファイルを削除 #####
+				if ($ret){
+					if ($delByContentId){		// コンテンツIDで削除のとき
+						$ret = $this->gInstance->getFileManager()->delAttachFileInfoByContentId(default_contentCommonDef::$_viewContentType,
+																								$contentId, default_contentCommonDef::getAttachFileDir());
+					} else {
+						$ret = $this->gInstance->getFileManager()->delAttachFileInfo(default_contentCommonDef::$_viewContentType,
+																						$this->serialNo, default_contentCommonDef::getAttachFileDir());
+					}
+				}
+				
 				if ($ret){		// データ削除成功のとき
 					$this->setGuidanceMsg('データを削除しました');
 					$reloadData = true;		// データの再読み込み
@@ -460,9 +528,36 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			} else {
 				$this->serialNo = 0;
 			}
+		} else if ($act == 'uploadfile'){		// 添付ファイルアップロード
+			$uploader = new qqFileUploader(array());
+			$resultObj = $uploader->handleUpload(default_contentCommonDef::getAttachFileDir());
+			
+			if ($resultObj['success']){
+				$fileInfo = $resultObj['file'];
+				$ret = $this->gInstance->getFileManager()->addAttachFileInfo(default_contentCommonDef::$_viewContentType, $fileInfo['fileid'], $fileInfo['path'], $fileInfo['filename']);
+				if (!$ret){			// エラーの場合はファイルを添付ファイルを削除
+					unlink($fileInfo['path']);
+					$resultObj = array('error' => 'Could not create file information.');
+				}
+			}
+			// ##### 添付ファイルアップロード結果を返す #####
+			// ページ作成処理中断
+			$this->gPage->abortPage();
+			
+			// 添付ファイルの登録データを返す
+			if (function_exists('json_encode')){
+				$destStr = json_encode($resultObj);
+			} else {
+				$destStr = $this->gInstance->getAjaxManager()->createJsonString($resultObj);
+			}
+			$destStr = htmlspecialchars($destStr, ENT_NOQUOTES);
+			header("Content-type: text/xml; charset=utf-8");
+			echo $destStr;
+			
+			// システム強制終了
+			$this->gPage->exitSystem();
 		} else {
 			// ##### コンテンツIDが設定されているとき(他ウィジェットからの表示)は、データを取得 #####
-			//$contentId = $request->trimValueOf('contentid');		// コンテンツID
 			if (empty($contentId)){
 				if (empty($this->serialNo)){		// 新規項目追加のとき
 					$visible = 1;		// 非公開で登録されてしまうので、初期状態は表示に設定
@@ -486,6 +581,8 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 					$this->serialNo = 0;
 				}
 			}
+			// ##### 初期表示時は仮登録の添付ファイルを削除 #####
+			$this->gInstance->getFileManager()->cleanAttachFileInfo(default_contentCommonDef::$_viewContentType, default_contentCommonDef::getAttachFileDir());
 		}
 		if ($reloadData){		// データの再読み込み
 			$ret = self::$_mainDb->getContentBySerial($this->serialNo, $row);
@@ -514,6 +611,23 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 				
 				// 履歴番号
 				if ($row['cn_deleted']) $histryIndex = $row['cn_history_index'];
+				
+				// ##### 添付ファイル情報を取得 #####
+				// 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
+				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){
+					$ret = $this->gInstance->getFileManager()->getAttachFileInfo(default_contentCommonDef::$_viewContentType, $this->serialNo, $rows);
+					if ($ret){
+						$this->attachFileInfoArray = array();
+						for ($i = 0; $i < count($rows); $i++){
+							$attachFileRow = $rows[$i];
+							$newInfoObj = new stdClass;
+							$newInfoObj->title		= $attachFileRow['af_title'];
+							$newInfoObj->filename	= $attachFileRow['af_filename'];
+							$newInfoObj->fileId		= $attachFileRow['af_file_id'];
+							$this->attachFileInfoArray[] = $newInfoObj;
+						}
+					}
+				}
 			} else {
 				$this->serialNo = 0;
 			}
@@ -544,6 +658,18 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 			$this->tmpl->addVar("show_singlelang", "sel_item_name", $name);		// 名前
 		}
 		
+		// 添付ファイル一覧作成
+		$this->createAttachFileList();
+		if (count($this->attachFileInfoArray) == 0) $this->tmpl->setAttribute('attach_file_list', 'visibility', 'hidden');// 添付ファイル一覧を表示
+		
+		// アップロード実行用URL
+		$uploadUrl = $this->gEnv->getDefaultAdminUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_CONFIG_WIDGET;	// ウィジェット設定画面
+		$uploadUrl .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();	// ウィジェットID
+		$uploadUrl .= '&' . M3_REQUEST_PARAM_OPERATION_TASK . '=' . 'content_detail';
+		$uploadUrl .= '&' . M3_REQUEST_PARAM_OPERATION_ACT . '=' . 'uploadfile';
+//		$uploadUrl .= '&path=' . $this->adaptWindowsPath($path);					// アップロードディレクトリ
+		$this->tmpl->addVar("_widget", "upload_url", $this->getUrl($uploadUrl));
+		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("_widget", "sel_item_html", $html);		// HTML
 		$this->tmpl->addVar("_widget", "sel_item_key", $key);		// 外部参照用キー
@@ -598,6 +724,16 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		$this->tmpl->addVar('_widget', 'admin_widget_id', self::ADMIN_WIDGET_ID);// ユーザ定義値参照用(管理ウィジェットのウィジェットID)
 		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
 		
+		// 拡張エリア制御ボタン
+		$iconUrl = $this->gEnv->getRootUrl() . self::OPEN_PANEL_ICON_FILE;		// 拡張エリア表示用アイコン
+		$iconTitle = 'オプション表示';
+		$openButton = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::PANEL_BUTTON_SIZE . '" height="' . self::PANEL_BUTTON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+		$this->tmpl->addVar('_widget', 'open_button', $openButton);
+		$iconUrl = $this->gEnv->getRootUrl() . self::CLOSE_PANEL_ICON_FILE;		// 拡張エリア非表示用アイコン
+		$iconTitle = 'オプション非表示';
+		$closeButton = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::PANEL_BUTTON_SIZE . '" height="' . self::PANEL_BUTTON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+		$this->tmpl->addVar('_widget', 'close_button', $closeButton);
+	
 		// ボタンの表示制御
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
 			if ($this->isMultiLang){		// 多言語対応の場合
@@ -971,5 +1107,29 @@ class admin_default_contentContentWidgetContainer extends admin_default_contentB
 		}
 		return $name;
 	}
+	/**
+	 * 添付ファイル一覧を作成
+	 *
+	 * @return なし						
+	 */
+	function createAttachFileList()
+	{
+		$fileCount = count($this->attachFileInfoArray);
+		for ($i = 0; $i < $fileCount; $i++){
+			$infoObj = $this->attachFileInfoArray[$i];
+			$title = $infoObj->title;		// タイトル
+			$filename = $infoObj->filename;		// ファイル名
+			$fileId = $infoObj->fileId;		// ファイルID
+			
+			$row = array(
+				'title' => $this->convertToDispString($title),
+				'filename' => $this->convertToDispString($filename),
+				'file_id' => $this->convertToDispString($fileId),
+				'root_url' => $this->convertToDispString($this->getUrl($this->gEnv->getRootUrl()))
+			);
+			$this->tmpl->addVars('attach_file_list', $row);
+			$this->tmpl->parseTemplate('attach_file_list', 'a');
+		}
+	}
 }
 ?>
