@@ -10,10 +10,10 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_default_contentOtherWidgetContainer.php 4929 2012-05-29 10:47:25Z fishbone $
+ * @version    SVN: $Id: admin_default_contentOtherWidgetContainer.php 4970 2012-06-15 10:51:03Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_default_contentBaseWidgetContainer.php');
+require_once($gEnvManager->getWidgetContainerPath('default_content') . '/admin_default_contentBaseWidgetContainer.php');
 
 class admin_default_contentOtherWidgetContainer extends admin_default_contentBaseWidgetContainer
 {
@@ -62,6 +62,11 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 		$usePassword	= ($request->trimValueOf('item_use_password') == 'on') ? 1 : 0;		// パスワードを使用するかどうか
 		$passwordContent = $request->valueOf('item_password_content');					// パスワード入力画面用コンテンツ
 		
+		// デバイスタイプごとの処理
+		if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
+			$jqueryMobileFormat	= ($request->trimValueOf('item_jquery_mobile_format') == 'on') ? 1 : 0;			// jQueryMobile用のフォーマットで出力するかどうか
+		}
+		
 		if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
 			
@@ -70,9 +75,15 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 				$paramObj->showMessageDeny = $showMessageDeny;					// アクセス不可の場合にメッセージを表示するかどうか
 				$paramObj->messageDeny = $messageDeny;							// アクセス不可の場合のメッセージ
 				$paramObj->showEdit	= $showEdit;			// 編集ボタンを表示するかどうか
+				
+				// デバイスタイプごとの処理
+				if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
+					$paramObj->jqueryMobileFormat = $jqueryMobileFormat;			// jQueryMobile用のフォーマットで出力するかどうか
+				}
+				
 				$ret = $this->updateWidgetParamObj($paramObj);
-				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::CF_USE_PASSWORD, $usePassword);		// パスワードを使用するかどうか
-				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::CF_PASSWORD_CONTENT, $passwordContent);		// パスワード入力画面用コンテンツ
+				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$CF_USE_PASSWORD, $usePassword);		// パスワードを使用するかどうか
+				if ($ret) $ret = self::$_mainDb->updateConfig(default_contentCommonDef::$CF_PASSWORD_CONTENT, $passwordContent);		// パスワード入力画面用コンテンツ
 		
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
@@ -90,17 +101,28 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 			$usePassword = 0;		// パスワードを使用するかどうか
 			$passwordContent = '';		// パスワード入力画面用コンテンツ
 			
+			// デバイスタイプごとの処理
+			if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
+				$jqueryMobileFormat = 1;			// jQueryMobile用のフォーマットで出力するかどうか
+			}
+			
 			$paramObj = $this->getWidgetParamObj();
 			if (!empty($paramObj)){
 				$showTitle = $paramObj->showTitle;			// コンテンツタイトルを表示するかどうか
 				$showMessageDeny = $paramObj->showMessageDeny;					// アクセス不可の場合にメッセージを表示するかどうか
 				$messageDeny = $paramObj->messageDeny;							// アクセス不可の場合のメッセージ
 				$showEdit = $paramObj->showEdit;			// 編集ボタンを表示するかどうか
+				
+				// デバイスタイプごとの処理
+				if (default_contentCommonDef::$_deviceType == 2){		// スマートフォンの場合
+					$jqueryMobileFormat = $paramObj->jqueryMobileFormat;			// jQueryMobile用のフォーマットで出力するかどうか
+				}
 			}
 			
-			$usePassword = self::$_mainDb->getConfig(default_contentCommonDef::CF_USE_PASSWORD);		// パスワードを使用するかどうか
-			$passwordContent = self::$_mainDb->getConfig(default_contentCommonDef::CF_PASSWORD_CONTENT);		// パスワード入力画面用コンテンツ
+			$usePassword = self::$_mainDb->getConfig(default_contentCommonDef::$CF_USE_PASSWORD);		// パスワードを使用するかどうか
+			$passwordContent = self::$_mainDb->getConfig(default_contentCommonDef::$CF_PASSWORD_CONTENT);		// パスワード入力画面用コンテンツ
 		}
+		
 		// 画面に書き戻す
 		$checked = '';
 		if (!empty($showTitle)) $checked = 'checked';
@@ -116,6 +138,21 @@ class admin_default_contentOtherWidgetContainer extends admin_default_contentBas
 		if (!empty($usePassword)) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "use_password", $checked);		// パスワードを使用するかどうか
 		$this->tmpl->addVar("_widget", "password_content", $passwordContent);		// パスワード入力画面用コンテンツ
+		
+		// デバイスタイプごとの画面作成
+		switch (default_contentCommonDef::$_deviceType){
+			case 0:		// PC
+				break;
+			case 1:		// 携帯
+				break;
+			case 2:		// スマートフォン
+				$this->tmpl->setAttribute('option_smartphone', 'visibility', 'visible');
+				
+				$checked = '';
+				if (!empty($jqueryMobileFormat)) $checked = 'checked';
+				$this->tmpl->addVar("option_smartphone", "jquery_mobile_format_checked", $checked);		// jQueryMobile用のフォーマットで出力するかどうか
+				break;
+		}
 	}
 }
 ?>
