@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 4981 2012-06-19 07:47:06Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 5027 2012-07-09 06:24:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('default_content') . '/default_contentBaseWidgetContainer.php');
@@ -19,6 +19,7 @@ require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
 class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 {
 	private $_contentCreated;	// コンテンツが取得できたかどうか
+	private $serialArray = array();		// 表示されているコンテンツシリアル番号
 	private $sessionParamObj;		// セッションパラメータ
 	private $currentDay;		// 現在日
 	private $currentHour;		// 現在時間
@@ -38,8 +39,10 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 	const CONTENT_SIZE = 200;			// 検索結果コンテンツの文字列最大長
 	const DEFAULT_MESSAGE_DENY = 'コンテンツを表示できません';		// アクセス不可の場合のメッセージ
 	const ICON_SIZE = 16;		// アイコンのサイズ
+	const DOWNLOAD_ICON_SIZE = 32;		// アイコンのサイズ
 	const EDIT_ICON_FILE = '/images/system/page_edit.png';		// 編集アイコン
 	const NEW_ICON_FILE = '/images/system/page_add.png';		// 新規アイコン
+	const DOWNLOAD_ICON_FILE = '/images/system/download32.png';		// 添付ファイルダウンロードアイコン
 	const DEFAULT_TITLE_SEARCH = 'コンテンツ検索';		// 検索時のデフォルトタイトル
 	const DEFAULT_TITLE_SEARCH_RESULTS = 'コンテンツ検索結果';	// 検索実行後のデフォルトタイトル
 	const EDIT_ICON_MIN_POS = 10;			// 編集アイコンの位置
@@ -163,7 +166,74 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 		$keyword = $request->trimValueOf('keyword');// 検索キーワード
 		$password = $request->trimValueOf('password');// パスワード
 		
-		if ($act == 'search'){			// 検索
+		if ($cmd == M3_REQUEST_CMD_DO_WIDGET){	// ウィジェット単体実行
+			$fileId = $request->trimValueOf('fileid');	// ファイルID
+			$canDownload = false;			// ダウンロード可能かどうか
+
+			// ファイルIDからコンテンツID取得
+			// 多言語の場合は添付ファイル情報と言語を合わせる必要がある
+			$contentId = '';
+			$ret = $this->gInstance->getFileManager()->getAttachFileInfoByFileId(default_contentCommonDef::$_viewContentType, $fileId, $attachFileRow);
+			if ($ret){
+				$contentId = $attachFileRow[af_content_id];
+				
+				// コンテンツへのアクセス可能状況をチェック
+				self::$_mainDb->getContentItems(default_contentCommonDef::$_contentType, array($this, 'checkItemsLoop'), array($contentId), $this->gEnv->getCurrentLanguage(), $all, $now, false);
+				if ($this->_contentCreated){		// コンテンツにアクセスできるとき
+					// パスワード入力のアクセス権はデフォルト言語でチェック
+					$ret = self::$_mainDb->getContentByContentId(default_contentCommonDef::$_contentType, $contentId, $this->gEnv->getDefaultLanguage(), $defaultContentRow);
+					if ($ret){
+						// アクセス権のチェック
+						$inputPassword = false;			// パスワード入力必要かどうか
+						if ($this->usePassword && !empty($defaultContentRow['cn_password'])){			// パスワードによるコンテンツ閲覧制限、かつ、パスワードが設定されている
+							// 認証状況をチェック
+							if (!is_array($this->sessionParamObj->authContentId) || !in_array($contentId, $this->sessionParamObj->authContentId)) $inputPassword = true;	// パスワード入力かどうか
+						}
+						if (!$inputPassword) $canDownload = true;		// ダウンロード可能
+					}
+				}
+			}
+			// ページ作成処理中断
+			$this->gPage->abortPage();
+							
+			if ($canDownload){		// ダウンロード可能なとき
+				// 添付ファイル情報を取得
+				$downloadCompleted = false;				// ダウンロード処理完了かどうか
+				$contentSerial = $this->serialArray[0];		// アクセス可能なコンテンツのシリアル番号
+				$ret = $this->gInstance->getFileManager()->getAttachFileInfo(default_contentCommonDef::$_viewContentType, $contentSerial, $attachFileRows);
+				if ($ret){
+					for ($i = 0; $i < count($attachFileRows); $i++){
+						$fileRow = $attachFileRows[$i];
+						if ($fileId == $fileRow['af_file_id']){
+							$downloadFile = default_contentCommonDef::getAttachFileDir() . DIRECTORY_SEPARATOR . $fileId;
+							$downloadFilename = $fileRow['af_filename'];
+							if (empty($downloadFilename)) $downloadFilename = $fileRow['af_original_filename'];
+							
+							// ダウンロード処理
+							$ret = $this->gPage->downloadFile($downloadFile, $downloadFilename);
+							$downloadCompleted = true;				// ダウンロード処理完了かどうか
+							break;
+						}
+					}
+				}
+				if ($downloadCompleted){		// ダウンロード処理完了のとき
+					// ダウンロードログを残す
+	//				if (!$this->isSystemManageUser){		// システム運用者以上の場合はカウントしない
+	//				}
+				} else {
+					$msgDetail = '';
+					if (!empty($contentId)) $msgDetail .= 'コンテンツID=' . $contentId;
+					$this->writeError(__METHOD__, '添付ファイルのダウンロードに失敗しました。添付ファイルが見つかりません。ファイルID=' . $fileId, 2200, $msgDetail);
+				}
+			} else {
+				// ダウンロード不可のときはエラーログを残す
+				$msgDetail = '';
+				if (!empty($contentId)) $msgDetail .= 'コンテンツID=' . $contentId;
+				$this->writeUserError(__METHOD__, '添付ファイルへの不正なアクセスを検出しました。ファイルID=' . $fileId, 2200, $msgDetail);
+			}
+			// システム強制終了
+			$this->gPage->exitSystem();
+		} else if ($act == 'search'){			// 検索
 			$itemCount = self::DEFAULT_SEARCH_LIST_COUNT;		// 取得数
 			
 			// キーワード検索のとき
@@ -419,6 +489,28 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 			$contentInfo[M3_TAG_MACRO_CONTENT_TITLE] = $fetchedRow['cn_name'];			// コンテンツ置換キー(タイトル)
 			$contentInfo[M3_TAG_MACRO_CONTENT_UPDATE_DT] = $fetchedRow['cn_create_dt'];		// コンテンツ置換キー(更新日時)
 			$contentText = $this->convertM3ToHtml($fetchedRow['cn_html'], true/*改行コーをbrタグに変換*/, $contentInfo);
+			
+			// 添付ファイルダウンロード用リンク
+			$attachFileTag = '';
+			$ret = $this->gInstance->getFileManager()->getAttachFileInfo(default_contentCommonDef::$_viewContentType, $fetchedRow['cn_serial'], $attachFileRows);
+			if ($ret){
+				$attachFileTag .= '<ul>';
+				for ($i = 0; $i < count($attachFileRows); $i++){
+					$fileTitle = $attachFileRows[$i]['af_title'];
+					if (empty($fileTitle)) $fileTitle = $attachFileRows[$i]['af_filename'];
+					
+					// ダウンロード用のリンク
+					$downloadUrl  = $this->gEnv->getDefaultUrl() . '?' . M3_REQUEST_PARAM_OPERATION_COMMAND . '=' . M3_REQUEST_CMD_DO_WIDGET;
+					$downloadUrl .= '&' . M3_REQUEST_PARAM_WIDGET_ID . '=' . $this->gEnv->getCurrentWidgetId();
+					$downloadUrl .= '&fileid=' . $attachFileRows[$i]['af_file_id'];
+						
+					$attachFileTag .= '<li>' . $this->convertToDispString($fileTitle);
+					$attachFileTag .= '<a href="' . $this->convertUrlToHtmlEntity($this->getUrl($downloadUrl)) . '">';
+					$attachFileTag .= '<img src="' . $this->getUrl($this->gEnv->getRootUrl() . self::DOWNLOAD_ICON_FILE) . '" width="' . self::DOWNLOAD_ICON_SIZE . '" height="' . self::DOWNLOAD_ICON_SIZE . '" title="ダウンロード" alt="ダウンロード" style="border:none;margin:0;padding:0;vertical-align:text-top;" />';
+					$attachFileTag .= '</a></li>';
+				}
+				$attachFileTag .= '</ul>';
+			}
 		}
 		
 		$headClassStr = $this->gDesign->getDefaultContentHeadClassString();			// コンテンツヘッダ用CSSクラス
@@ -451,7 +543,8 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 			'content_id' => $contentId,
 			'func_name'	=> $funcName,	// パスワードチェック用関数
 			'form_name'	=> $formName,	// パスワードチェック用フォーム名
-			'button_list' => $buttonList	// 記事編集ボタン
+			'button_list' => $buttonList,	// 記事編集ボタン
+			'download' => $attachFileTag	// 添付ファイル
 		);
 		$this->tmpl->addVars('contentlist', $row);
 		$this->tmpl->parseTemplate('contentlist', 'a');
@@ -460,6 +553,21 @@ class default_contentWidgetContainer extends default_contentBaseWidgetContainer
 		$this->_contentCreated = true;
 		return true;
 	}
+	/**
+	 * 取得したコンテンツ項目をテンプレートに設定する
+	 *
+	 * @param int		$index			行番号
+	 * @param array		$fetchedRow		取得行
+	 * @param object	$param			任意使用パラメータ
+	 * @return bool						trueを返すとループ続行。falseを返すとその時点で終了。
+	 */
+	function checkItemsLoop($index, $fetchedRow)
+	{
+		$this->serialArray[] = $fetchedRow['cn_serial'];// コンテンツのシリアル番号を保存
+		
+		$this->_contentCreated = true;// コンテンツが取得できた
+		return true;
+	}
 	/**
 	 * 取得したコンテンツ項目をテンプレートに設定する
 	 *
