@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 4923 2012-05-25 14:05:22Z fishbone $
+ * @version    SVN: $Id: index.php 5023 2012-07-09 03:48:02Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -64,6 +64,8 @@ $HELP['content_meta_description']['title'] = 'ページ要約';
 $HELP['content_meta_description']['body'] = 'ヘッダ部のdescriptionタグに設定される文字列です。120文字程度で記述します。<br />Googleでは検索結果に表示されます。';
 $HELP['content_meta_keywords']['title'] = '検索キーワード';
 $HELP['content_meta_keywords']['body'] = 'ヘッダ部のkeywordsタグに設定される文字列です。検索エンジン用のキーワードを「,」区切りで10個以下で記述します。';
+$HELP['content_attach_file']['title'] = '添付ファイル';
+$HELP['content_attach_file']['body'] = 'コンテンツに添付するファイルを指定します。ファイルを追加するには、「ファイルアップロード」領域にファイルをドロップするか、クリックで表示したダイアログでファイルを選択します。';
 
 $HELP['content_new_btn']['title'] = '新規ボタン';
 $HELP['content_new_btn']['body'] = '新規コンテンツを追加します。';
