@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_menuWidgetContainer.php 4896 2012-05-01 05:22:52Z fishbone $
+ * @version    SVN: $Id: default_menuWidgetContainer.php 4937 2012-06-05 09:44:57Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -199,7 +199,8 @@ class default_menuWidgetContainer extends BaseWidgetContainer
 				}
 				
 				// メニュー項目を作成
-				$name = $row['md_name'];
+				//$name = $row['md_name'];
+				$name = $this->getCurrentLangString($row['md_name']);
 				if (empty($name)) continue;
 				
 				$index++;		// インデックス番号更新
