@@ -10,13 +10,13 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_menuWidgetContainer.php 2048 2009-07-07 06:12:22Z fishbone $
+ * @version    SVN: $Id: admin_ec_menuWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/ec_menuDb.php');
 
-class admin_ec_menuWidgetContainer extends BaseWidgetContainer
+class admin_ec_menuWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
@@ -127,7 +127,6 @@ class admin_ec_menuWidgetContainer extends BaseWidgetContainer
 		$this->db->getAllMenuItems(array($this, 'itemListLoop'), self::EC_MENU_ID, $this->langId);
 
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
-		$this->tmpl->addVar('_widget', 'admin_url', $this->gEnv->getDefaultAdminUrl());// 管理者URL
 	}
 	/**
 	 * 詳細画面作成
@@ -279,7 +278,7 @@ class admin_ec_menuWidgetContainer extends BaseWidgetContainer
 				// コンテンツを取得
 				$ret = $this->db->getContentByContentId(self::CONTENT_TYPE, $contentId, $this->langId, $row);
 				if ($ret){
-					$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $row['cn_html']);// アプリケーションルートを変換
+					$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->getUrl($this->gEnv->getRootUrl()), $row['cn_html']);// アプリケーションルートを変換
 				}
 			}
 		}
@@ -292,8 +291,8 @@ class admin_ec_menuWidgetContainer extends BaseWidgetContainer
 		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("_widget", "sel_item_name", $name);		// 名前
-		$this->tmpl->addVar("_widget", "sel_item_url", $url);		// URL
-		$this->tmpl->addVar("_widget", "save_url", $url);		// URL
+		$this->tmpl->addVar("_widget", "sel_item_url", $this->getUrl($url, true));		// URL
+		$this->tmpl->addVar("_widget", "save_url", $this->getUrl($url, true));		// URL
 		$this->tmpl->addVar("_widget", "sel_item_html", $html);		// ヘッダコンテンツ
 		
 		// リンクタイプ
@@ -318,8 +317,6 @@ class admin_ec_menuWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "sel_item_enable", $enableStr);
 		
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
-		$this->tmpl->addVar("_widget", "root_url", $this->gEnv->getRootUrl());// FCKEditor用
-		$this->tmpl->addVar("_widget", "widget_sc_url", $this->gEnv->getCurrentWidgetScriptsUrl());// FCKEditor用
 
 		// ボタンの表示制御
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
@@ -401,7 +398,7 @@ class admin_ec_menuWidgetContainer extends BaseWidgetContainer
 				break;
 		}
 		// リンク先URL作成
-		$linkUrl = $this->gPage->getDefaultPageUrlByWidget(self::VIEW_WIDGET, $fetchedRow['mi_param']);
+		$linkUrl = $this->getUrl($this->gPage->getDefaultPageUrlByWidget(self::VIEW_WIDGET, $fetchedRow['mi_param']), true);
 		$linkUrlStr = '<div style="overflow:auto;"><a href="#" onClick="showUrl(\'' . $linkUrl . '\');">' . $linkUrl . '</a></div>';
 		
 		// カテゴリー名を取得
