@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4645 2012-02-01 09:08:41Z fishbone $
+ * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4995 2012-06-27 13:07:16Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -48,6 +48,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	private $isExistsProduct;		// 商品が存在するかどうか
 	private $prePrice;		// 価格表示用
 	private $postPrice;		// 価格表示用
+	private $categoryWithPwdArray;	// パスワードが必要なカテゴリー
 	const CSS_FILE = '/style.css';		// CSSファイルのパス
 	const NOT_FOUND_ICON_FILE = 		'/images/system/notfound128.gif';		// 写真が見つからないアイコン
 	const BACK_ICON_FILE = '/images/system/back.png';		// 「戻る」アイコン
@@ -271,15 +272,31 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 				}
 			}
 			$this->tmpl->setAttribute('category_script', 'visibility', 'visible');		// 画像カテゴリースクリプト表示
-			$this->tmpl->setAttribute('category_area', 'visibility', 'visible');		// 画像カテゴリーエリア表示
 
 			// 画像カテゴリー選択メニュー作成
+			$this->categoryWithPwdArray = array();	// パスワードが必要なカテゴリー
 			$this->authCategoryStr = '';
 			$this->categoryDb->getAllCategory($this->_langId, array($this, 'categoryListLoop'), true);
-		
-			// 参照可能カテゴリー表示
-			$this->authCategoryStr = rtrim($this->authCategoryStr, ', ');
-			$this->tmpl->addVar("category_area", "auth_category_list", $this->convertToDispString($this->authCategoryStr));
+			
+			$categoryWithPwdCount = count($this->categoryWithPwdArray);
+			if ($categoryWithPwdCount > 1){		// パスワードが必要なカテゴリーが複数の場合
+				// 認証されていないカテゴリーがある場合のみ表示
+				for ($i = 0; $i < $categoryWithPwdCount; $i++){
+					if (!in_array($this->categoryWithPwdArray[$i], $this->authCategory)) break;		// 認証されていないとき
+				}
+				if ($i < $categoryWithPwdCount){
+					$this->tmpl->setAttribute('category_area', 'visibility', 'visible');		// 画像カテゴリーエリア表示
+			
+					// 参照可能カテゴリー表示
+					$this->authCategoryStr = rtrim($this->authCategoryStr, ', ');
+					$this->tmpl->addVar("category_area", "auth_category_list", $this->convertToDispString($this->authCategoryStr));
+				}
+			} else if ($categoryWithPwdCount == 1){		// 参照可能なカテゴリーが単数のとき
+				if (!in_array($this->categoryWithPwdArray[0], $this->authCategory)){		// 認証されていないとき
+					$this->tmpl->addVar("single_category_area", "value", $this->convertToDispString($this->categoryWithPwdArray[0]));
+					$this->tmpl->setAttribute('single_category_area', 'visibility', 'visible');		// 画像カテゴリーエリア表示
+				}
+			}
 		}
 		
 		// データエラーチェック
@@ -971,6 +988,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$id = $fetchedRow['hc_id'];// カテゴリ項目ID
 		$name = $fetchedRow['hc_name'];		// カテゴリ項目名
 		$selected = '';
+		$this->categoryWithPwdArray[] = $id;	// パスワードが必要なカテゴリー
 		
 		// 既にアクセス可能になっているカテゴリーは表示しない
 		if (in_array($id, $this->authCategory)){
@@ -1332,7 +1350,8 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	{
 		$serializedParam = self::$_mainDb->getClientParam($clientId, $widgetId);
 		if (empty($serializedParam)){
-			return null;
+			$clientObj = new stdClass;
+			return $clientObj;
 		} else {
 			return unserialize($serializedParam);
 		}
